==> jside-0.0.3.tgz: package/index.js <==
let electron = require('electron');
let EventEmitter = require('events');
let au = require("./addUtils.js")
let exec = require('child_process').exec
let execSync = require('child_process').execSync
let event = new EventEmitter()
let canConnect = true
let windows = {}
module.exports.run = () => {

  let socket
  let sockets = {}
  let port = au.randomInt(1824, 30800)
  let io = require("socket.io")(port)

  io.on("connection", sckt => {

    if (canConnect) {
      canConnect = false
      socket = sckt
      run()
    }
  })

  function run() {

    module.exports.CreateWindow = (cfg) => {
      let wid = "w" + au.randomInt(999, 99999999999999999999999999999999999)
      if (typeof cfg !== "object" || cfg == undefined) {
        cfg = {}
      }
      if (!cfg.w) {
        cfg.w = 500
      }
      if (!cfg.h) {
        cfg.h = 500
      }
      if (!cfg.fullscreen) {
        cfg.fullscreen = false
      }
      if (!cfg.windowManager) {
        cfg.windowManager = true
      }
      if (!cfg.resizable) {
        cfg.resizable = false
      }
      socket.emit("newWindow", cfg, wid)
      let e = new EventEmitter()
      socket.on("windowAction", (opts) => {
        if (opts.wid != wid) {
          return
        } else {
          e.emit(opts.action, opts.data)
        }
      })

      let sync = true
      io.of("/" + wid).once("connection", sckt => {

        windows[wid] = {
          cfg: cfg,
          events: e,
          socket: sckt
        }
        sync = false
        sckt.on("disconnect", () => {
          e.emit("close")
        })

      })
      while (sync) {
        au.sleep(10)
      }
      return ()=>{return fetchWindow(wid)}
    }
    socket.on('windowResize', (args) => {
      windows[args.wid].events.emit("resize",args.data)
      windows[args.wid].cfg.h=args.data.h
      windows[args.wid].cfg.w=args.data.w
    })
    socket.on("disconnect", () => {
      canConnect = true
      exec(electron + " " + __dirname + "/main.js " + port)
    })

    socket.on("all-windows-closed", () => {
      event.emit("all-windows-closed")
    })
    event.emit("ready")
  }

  function fetchWindow(wid) {
    return {
      id: wid,
      e: windows[wid].events,
      execJS: (code) => {
        let rid=au.randomString(100)
        socket.emit("windowExec", {
          rid:rid,
          wid: wid,
          code: code
        })
        let sync=true
        result=null
        socket.on("execResult",function rh(res){
          if(res.rid!=rid){return}
          sync=false
          result=res.data
          socket.removeListener("execResult",rh)
        })
        while(sync){au.sleep(20)}
        return result
      },
      w: windows[wid].cfg.w,
      h: windows[wid].cfg.h,
      socket: windows[wid].socket,
      addButton:(name,x,y)=>{
        let ww=fetchWindow(wid)
        let xpx=(ww.w/2)+x/2+"px"
        let ypx=ww.h/2+y/2+"px"
        let bid = "b" + au.randomInt(999, 99999999999999999999999999999999999)
        ww.execJS(`MakeElement("button",{id:"${bid}",innerHTML:"${name}",class:"btn btn-primary bg-light cf",style:"position:absolute;color:black;top:${ypx};left:${xpx}"})`)
      }
    }
  }

  exec(electron + " " + __dirname + "/main.js " + port)
  return event;
}

==> jside-0.0.4.tgz: package/index.js <==
let electron = require('electron');
let EventEmitter = require('events');
let au = require("./addUtils.js")
let exec = require('child_process').exec
let execSync = require('child_process').execSync
let event = new EventEmitter()
let canConnect = true
let windows = {}
module.exports.run = () => {

  let socket
  let sockets = {}
  let port = au.randomInt(1824, 30800)
  let io = require("socket.io")(port)

  io.on("connection", sckt => {

    if (canConnect) {
      canConnect = false
      socket = sckt
      run()
    }
  })

  function run() {

    module.exports.CreateWindow = (cfg) => {
      let wid = "w" + au.randomInt(999, 99999999999999999999999999999999999)
      if (typeof cfg !== "object" || cfg == undefined) {
        cfg = {}
      }
      if (!cfg.w) {
        cfg.w = 500
      }
      if (!cfg.h) {
        cfg.h = 500
      }
      if (!cfg.fullscreen) {
        cfg.fullscreen = false
      }
      if (!cfg.windowManager) {
        cfg.windowManager = true
      }
      if (!cfg.resizable) {
        cfg.resizable = false
      }
      socket.emit("newWindow", cfg, wid)
      let e = new EventEmitter()
      socket.on("windowAction", (opts) => {
        if (opts.wid != wid) {
          return
        } else {
          e.emit(opts.action, opts.data)
        }
      })

      let sync = true
      io.of("/" + wid).once("connection", sckt => {

        windows[wid] = {
          cfg: cfg,
          events: e,
          socket: sckt
        }
        sync = false
        sckt.on("disconnect", () => {
          e.emit("close")
        })

      })
      while (sync) {
        au.sleep(10)
      }
      return ()=>{return fetchWindow(wid)}
    }
    socket.on('windowResize', (args) => {
      windows[args.wid].events.emit("resize",args.data)
      windows[args.wid].cfg.h=args.data.h
      windows[args.wid].cfg.w=args.data.w
    })
    socket.on("disconnect", () => {
      canConnect = true
      exec(electron + " " + __dirname + "/main.js " + port)
    })

    socket.on("all-windows-closed", () => {
      event.emit("all-windows-closed")
    })
    event.emit("ready")
  }

  function fetchWindow(wid) {
    return {
      id: wid,
      e: windows[wid].events,
      execJS: (code) => {
        let rid=au.randomString(100)
        socket.emit("windowExec", {
          rid:rid,
          wid: wid,
          code: code
        })
        let sync=true
        result=null
        socket.on("execResult",function rh(res){
          if(res.rid!=rid){return}
          sync=false
          result=res.data
          socket.removeListener("execResult",rh)
        })
        while(sync){au.sleep(20)}
        return result
      },
      w: windows[wid].cfg.w,
      h: windows[wid].cfg.h,
      socket: windows[wid].socket,
      addButton:(name,x,y)=>{
        let ww=fetchWindow(wid)
        let xpx=ww.w/2+x+"px"
        let ypx=ww.h/2+y+"px"
        let bid = "b" + au.randomString(10)
        ww.execJS(`MakeElement("button",{id:"${bid}",innerHTML:"${name}",class:"btn btn-primary bg-light cf",style:"position:absolute;color:black;top:${ypx};left:${xpx}"})`)
        return fetchButton(wid,bid)
      }
    }
  }
  function fetchButton(wid,bid) {
    return {
      setPosition:(x,y)=>{
        let ww=fetchWindow(wid)
        let xpx=ww.w/2+x+"px"
        let ypx=ww.h/2+y+"px"
      fetchWindow(wid).execJS(`document.getElementById('${bid}').style.top='${ypx}';\ndocument.getElementById('${bid}').style.left='${xpx}'`)
      }
    }
  }
  exec(electron + " " + __dirname + "/main.js " + port)
  return event;
}
